@@ -1,7 +1,8 @@
 LRbounds<-function(x,  dist="weibull", CL=0.9, unrel=NULL,  contour=NULL, dof=1, control=NULL, debias="none", show=c(FALSE,FALSE)) {							
 							
 ## check basic parameters of x							
-	if(class(x)!="data.frame") {stop("mlefit takes a structured dataframe input, use mleframe")}						
+	#if(class(x)!="data.frame") stop("FMbounds takes a structured dataframe input, use mleframe")	
+	if(!is(x, "data.frame")) stop("LRbounds takes a structured dataframe input, use mleframe")					
 	if(ncol(x)!=3)  {stop("mlefit takes a structured dataframe input, use mleframe")}						
 	xnames<-names(x)						
 	if(xnames[1]!="left" || xnames[2]!="right"||xnames[3]!="qty")  {						
